# Impressum

## Anbieterkennzeichnung gemäß § 18 Abs. 2 MStV

**Name**  
Til Schwarze

**Anschrift**  
Marktplatz 19  
72108 Rottenburg am Neckar  
Deutschland

**Kontakt**  
E-Mail: [info@envseal.org](mailto:info@envseal.org)

**Verantwortlich für journalistisch-redaktionelle Inhalte (§ 18 Abs. 2 MStV)**  
Til Schwarze

---

## Haftungsausschluss

### Inhalte

Die Inhalte dieser Website werden mit größter Sorgfalt erstellt. Für die Richtigkeit, Vollständigkeit und Aktualität wird keine Gewähr übernommen. Als Anbieter bin ich für eigene Inhalte nach den allgemeinen Gesetzen verantwortlich. Eine Verpflichtung zur Überwachung fremder Informationen besteht nicht. Eine Haftung ist erst ab Kenntnis konkreter Rechtsverletzungen möglich. Entsprechende Inhalte werden bei Bekanntwerden entfernt.

### Externe Links

Diese Website enthält Links zu externen Seiten Dritter, auf deren Inhalte ich keinen Einfluss habe. Für diese Inhalte wird keine Gewähr übernommen. Verantwortlich sind die jeweiligen Betreiber. Zum Zeitpunkt der Verlinkung waren keine rechtswidrigen Inhalte erkennbar. Bei Bekanntwerden von Rechtsverletzungen werden entsprechende Links entfernt.

### Urheberrecht

Die auf dieser Website veröffentlichten Inhalte unterliegen dem deutschen Urheberrecht. Vervielfältigung oder Verwertung außerhalb der Grenzen des Urheberrechts bedürfen der Zustimmung des jeweiligen Urhebers. Downloads und Kopien sind nur für den privaten, nicht-kommerziellen Gebrauch erlaubt.

Inhalte Dritter werden entsprechend gekennzeichnet. Bei Hinweisen auf Urheberrechtsverletzungen bitte ich um Mitteilung; betroffene Inhalte werden entfernt.